Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PodLabelConfigLister ¶
type PodLabelConfigLister interface {
// List lists all PodLabelConfigs in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.PodLabelConfig, err error)
// PodLabelConfigs returns an object that can list and get PodLabelConfigs.
PodLabelConfigs(namespace string) PodLabelConfigNamespaceLister
PodLabelConfigListerExpansion
}
PodLabelConfigLister helps list PodLabelConfigs.
func NewPodLabelConfigLister ¶
func NewPodLabelConfigLister(indexer cache.Indexer) PodLabelConfigLister
NewPodLabelConfigLister returns a new PodLabelConfigLister.
type PodLabelConfigListerExpansion ¶
type PodLabelConfigListerExpansion interface{}
PodLabelConfigListerExpansion allows custom methods to be added to PodLabelConfigLister.
type PodLabelConfigNamespaceLister ¶
type PodLabelConfigNamespaceLister interface {
// List lists all PodLabelConfigs in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.PodLabelConfig, err error)
// Get retrieves the PodLabelConfig from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.PodLabelConfig, error)
PodLabelConfigNamespaceListerExpansion
}
PodLabelConfigNamespaceLister helps list and get PodLabelConfigs.
type PodLabelConfigNamespaceListerExpansion ¶
type PodLabelConfigNamespaceListerExpansion interface{}
PodLabelConfigNamespaceListerExpansion allows custom methods to be added to PodLabelConfigNamespaceLister.
Click to show internal directories.
Click to hide internal directories.